@@ -14,8 +14,8 @@ def main():
     if pie is not None:
         os.remove(pie)
 
-    pie_manager_path = shutil.which("pie-manager")
-    if pie_manager_path is not None:
+    pie_manager_path = shutil.which("pie_manager")
+    if pie_manager_path is None:
         print(Fore.RED + "Please reinstall Pie Manager." + Fore.RESET)
         exit()
 
